@@ -229,16 +229,47 @@ void VlcMediaWidget::resizeToVideo(float resizeFactor)
 	libvlc_video_set_scale(vlcMediaPlayer, resizeFactor);
 }
 
-void VlcMediaWidget::setDeinterlacing(bool deinterlacing)
+void VlcMediaWidget::setDeinterlacing(MediaWidget::DeinterlaceMode deinterlacing)
 {
-	// "", "blend", "bob", "discard", "ivtc", "linear",
-	// "mean", "phosphor", "x", "yadif", "yadif2x"
-	const char *vlcDeinterlaceMode = "";
+	const char *vlcDeinterlaceMode;
 
-	if (deinterlacing) {
+	switch (deinterlacing) {
+	case MediaWidget::DeinterlaceDiscard:
+		vlcDeinterlaceMode = "discard";
+		break;
+	case MediaWidget::DeinterlaceBob:
+		vlcDeinterlaceMode = "bob";
+		break;
+	case MediaWidget::DeinterlaceLinear:
+		vlcDeinterlaceMode = "linear";
+		break;
+	case MediaWidget::DeinterlaceYadif:
 		vlcDeinterlaceMode = "yadif";
+		break;
+	case MediaWidget::DeinterlaceYadif2x:
+		vlcDeinterlaceMode = "yadif2x";
+		break;
+	case MediaWidget::DeinterlacePhosphor:
+		vlcDeinterlaceMode = "phosphor";
+		break;
+	case MediaWidget::DeinterlaceX:
+		vlcDeinterlaceMode = "x";
+		break;
+	case MediaWidget::DeinterlaceMean:
+		vlcDeinterlaceMode = "mean";
+		break;
+	case MediaWidget::DeinterlaceBlend:
+		vlcDeinterlaceMode = "blend";
+		break;
+	case MediaWidget::DeinterlaceIvtc:
+		vlcDeinterlaceMode = "ivtc";
+		break;
+	case MediaWidget::DeinterlaceDisabled:
+	default:
+		vlcDeinterlaceMode = NULL;
 	}
 
+
 	libvlc_video_set_deinterlace(vlcMediaPlayer, vlcDeinterlaceMode);
 }
 
@@ -630,12 +661,34 @@ void VlcMediaWidget::updateVideoSize()
 	// FIXME
 }
 
+void VlcMediaWidget::dvdNavigate(int key)
+{
+	int event;
+
+	switch (key){
+	case Qt::Key_Return:
+		event = libvlc_navigate_activate;
+		break;
+	case Qt::Key_Up:
+		event = libvlc_navigate_up;
+		break;
+	case Qt::Key_Down:
+		event = libvlc_navigate_down;
+		break;
+	case Qt::Key_Left:
+		event = libvlc_navigate_left;
+		break;
+	case Qt::Key_Right:
+		event = libvlc_navigate_right;
+		break;
+	default:
+		return;
+	}
+	libvlc_media_player_navigate(vlcMediaPlayer, event);
+}
+
 void VlcMediaWidget::mousePressEvent(QMouseEvent *event)
 {
-	if (event->button() == Qt::LeftButton) {
-		libvlc_media_player_navigate(vlcMediaPlayer, libvlc_navigate_activate);
-	}
-
 	AbstractMediaWidget::mousePressEvent(event);
 }
 
@@ -649,13 +702,11 @@ void VlcMediaWidget::hideMouse()
 
 void VlcMediaWidget::mouseMoveEvent(QMouseEvent *event)
 {
-	mouseVisible = this->rect().contains(event->pos());
-
 	if (!timer->isActive()) {
 		setCursor(Qt::BlankCursor);
 		setCursor(Qt::ArrowCursor);
 	}
-	if (mouseVisible)
+	if (this->underMouse())
 		timer->start(1000);
 	else
 		timer->stop();
