@@ -190,7 +190,9 @@ void DvbLiveView::replay()
 				i18nc("@info", "All devices are used for recordings."));
 		} else {
 			KMessageBox::information(manager->getParentWidget(),
-				i18nc("@info", "No device found."));
+				i18nc("@info",
+				      "Didn't find a device with valid settings or access permissions are wrong.\n\n"
+				      "Please check the Configure Television window."));
 		}
 
 		return;
@@ -366,8 +368,7 @@ void DvbLiveView::deviceStateChanged()
 			startDevice();
 		} else {
 			mediaWidget->stop();
-			osdWidget->showText(i18nc("message box", "No available device found."),
-				2500);
+			osdWidget->showText(i18nc("message box", "No available device found."), 2500);
 		}
 
 		break;
