@@ -74,6 +74,7 @@ DvbDevice *DvbManager::requestDevice(const QString &source, const DvbTransponder
 	Q_ASSERT(requestType != Exclusive);
 	// FIXME call DvbEpgModel::startEventFilter / DvbEpgModel::stopEventFilter here?
 
+	reacquireDevice = false;
 	for (int i = 0; i < deviceConfigs.size(); ++i) {
 		const DvbDeviceConfig &it = deviceConfigs.at(i);
 
@@ -142,6 +143,7 @@ DvbDevice *DvbManager::requestDevice(const QString &source, const DvbTransponder
 				DvbDevice *device = it.device;
 				device->reacquire(config.constData());
 				device->tune(transponder);
+				reacquireDevice = true;
 				return device;
 			}
 		}
@@ -605,6 +607,7 @@ void DvbManager::loadDeviceManager()
 void DvbManager::readDeviceConfigs()
 {
 	QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/config.dvb"));
+	const char *errMsg;
 
 	if (!file.open(QIODevice::ReadOnly)) {
 		qCWarning(logDvb, "Cannot open %s", qPrintable(file.fileName()));
@@ -623,6 +626,7 @@ void DvbManager::readDeviceConfigs()
 		int configCount = reader.readInt(QLatin1String("configCount"));
 
 		if (!reader.isValid()) {
+			errMsg = "device section invalid";
 			break;
 		}
 
@@ -639,28 +643,32 @@ void DvbManager::readDeviceConfigs()
 				reader.readEnum(QLatin1String("type"), DvbConfigBase::TransmissionTypeMax);
 
 			if (!reader.isValid()) {
+				errMsg = "transmission type invalid";
 				break;
 			}
 
 			DvbConfigBase *config = new DvbConfigBase(type);
+
 			config->numberOfTuners = 1;
 			config->name = reader.readString(QLatin1String("name"));
 			config->scanSource = reader.readString(QLatin1String("scanSource"));
 			config->timeout = reader.readInt(QLatin1String("timeout"));
-			config->higherVoltage = reader.readInt(QLatin1String("higherVoltage"));
 
 			if (type == DvbConfigBase::DvbS) {
 				config->latitude = 0;
 				config->longitude = 0;
+				config->higherVoltage = Qt::PartiallyChecked;
 				config->configuration = reader.readEnum(QLatin1String("configuration"),
 					DvbConfigBase::ConfigurationMax);
 				config->lnbNumber = reader.readInt(QLatin1String("lnbNumber"));
 				config->currentLnb.alias = reader.readString(QLatin1String("lnb"));
 				config->latitude = reader.readDouble(QLatin1String("latitude"));
 				config->longitude = reader.readInt(QLatin1String("longitude"));
+				config->higherVoltage = reader.readInt(QLatin1String("higherVoltage"));
 			}
 
 			if (!reader.isValid()) {
+				errMsg = "DVB device data invalid";
 				delete config;
 				break;
 			}
@@ -672,7 +680,7 @@ void DvbManager::readDeviceConfigs()
 	}
 
 	if (!reader.isValid())
-		qCWarning(logDvb, "Cannot read %s", qPrintable(file.fileName()));
+		qCWarning(logDvb, "Found some problems at %s: %s", qPrintable(file.fileName()), errMsg);
 }
 
 void DvbManager::writeDeviceConfigs()
@@ -699,7 +707,6 @@ void DvbManager::writeDeviceConfigs()
 			writer.write(QLatin1String("name"), config->name);
 			writer.write(QLatin1String("scanSource"), config->scanSource);
 			writer.write(QLatin1String("timeout"), config->timeout);
-			writer.write(QLatin1String("higherVoltage"), config->higherVoltage);
 
 			if (config->getTransmissionType() == DvbConfigBase::DvbS) {
 				writer.write(QLatin1String("configuration"), config->configuration);
@@ -707,6 +714,7 @@ void DvbManager::writeDeviceConfigs()
 				writer.write(QLatin1String("lnb"), config->currentLnb.alias);
 				writer.write(QLatin1String("latitude"), config->latitude);
 				writer.write(QLatin1String("longitude"), config->longitude);
+				writer.write(QLatin1String("higherVoltage"), config->higherVoltage);
 			}
 		}
 	}
