@@ -405,39 +405,8 @@ void MainWindow::run()
 #endif /* HAVE_DVB == 1 */
 	QDBusConnection::sessionBus().registerService(QLatin1String("org.mpris.kaffeine"));
 
-	show();
-
-	// set display mode
-	switch (Configuration::instance()->getStartupDisplayMode()) {
-	case Configuration::StartupNormalMode:
-		// nothing to do
-		break;
-	case Configuration::StartupMinimalMode:
-		mediaWidget->setDisplayMode(MediaWidget::MinimalMode);
-		break;
-	case Configuration::StartupFullScreenMode:
-		mediaWidget->setDisplayMode(MediaWidget::FullScreenMode);
-		break;
-	case Configuration::StartupRememberLastSetting: {
-		int value = KSharedConfig::openConfig()->group("MainWindow").readEntry("DisplayMode", 0);
-
-		switch (value) {
-		case 0:
-			// nothing to do
-			break;
-		case 1:
-			mediaWidget->setDisplayMode(MediaWidget::MinimalMode);
-			break;
-		case 2:
-			mediaWidget->setDisplayMode(MediaWidget::FullScreenMode);
-			break;
-		}
-
-		break;
-	    }
-	}
-
 	parseArgs();
+	show();
 }
 
 MainWindow::~MainWindow()
@@ -500,6 +469,8 @@ MainWindow::MainWindow(KAboutData *aboutData, QCommandLineParser *parser)
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("d") << QLatin1String("debug"), i18n("Enable all debug messages. Please notice that Kaffeine also allows enabling debug messages per category, by using the environment var:\nQT_LOGGING_RULES=kaffeine.category.debug=true\nwhere 'category' can be:\n" CATEGORIES)));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("tempfile"), i18n("The files/URLs opened by the application will be deleted after use")));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("f") << QLatin1String("fullscreen"), i18n("Start in full screen mode")));
+	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("m") << QLatin1String("minimal"), i18n("Start in minimal mode")));
+	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("t") << QLatin1String("alwaysontop"), i18n("Start with always on top")));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("audiocd"), i18n("Play Audio CD")));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("videocd"), i18n("Play Video CD")));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("dvd"), i18n("Play DVD")));
@@ -515,10 +486,6 @@ MainWindow::MainWindow(KAboutData *aboutData, QCommandLineParser *parser)
 
 void MainWindow::parseArgs(const QString workingDirectory)
 {
-	if (parser->isSet("fullscreen")) {
-		mediaWidget->setDisplayMode(MediaWidget::FullScreenMode);
-	}
-
 	if (parser->isSet("audiocd")) {
 		if (parser->positionalArguments().count() > 0) {
 			openAudioCd(parser->positionalArguments().first());
@@ -574,7 +541,6 @@ void MainWindow::parseArgs(const QString workingDirectory)
 		activateTab(DvbTabId);
 		dvbTab->playLastChannel();
 
-
 		return;
 	}
 #endif /* HAVE_DVB == 1 */
@@ -601,6 +567,48 @@ void MainWindow::parseArgs(const QString workingDirectory)
 			openUrl(urls.at(0));
 		}
 	}
+
+	if (parser->isSet("alwaysontop")) {
+		Qt::WindowFlags flags = this->windowFlags();
+		flags |= Qt::WindowStaysOnTopHint;
+		this->setWindowFlags(flags);
+	}
+
+	if (parser->isSet("fullscreen")) {
+		mediaWidget->setDisplayMode(MediaWidget::FullScreenMode);
+	} else if (parser->isSet("minimal")) {
+		mediaWidget->setDisplayMode(MediaWidget::MinimalMode);
+	} else {
+		// set display mode
+		switch (Configuration::instance()->getStartupDisplayMode()) {
+		case Configuration::StartupNormalMode:
+			// nothing to do
+			break;
+		case Configuration::StartupMinimalMode:
+			mediaWidget->setDisplayMode(MediaWidget::MinimalMode);
+			break;
+		case Configuration::StartupFullScreenMode:
+			mediaWidget->setDisplayMode(MediaWidget::FullScreenMode);
+			break;
+		case Configuration::StartupRememberLastSetting: {
+			int value = KSharedConfig::openConfig()->group("MainWindow").readEntry("DisplayMode", 0);
+
+			switch (value) {
+			case 0:
+				// nothing to do
+				break;
+			case 1:
+				mediaWidget->setDisplayMode(MediaWidget::MinimalMode);
+				break;
+			case 2:
+				mediaWidget->setDisplayMode(MediaWidget::FullScreenMode);
+				break;
+			}
+
+			break;
+		} /* case */
+		} /* switch */
+	}
 }
 
 void MainWindow::displayModeChanged()
@@ -764,10 +772,14 @@ void MainWindow::activateTab(int tabIndex)
 	currentTabIndex = tabIndex;
 	tabBar->setCurrentIndex(tabIndex);
 
-	if (!autoHideControlBar) {
-		stackedLayout->setCurrentIndex(currentTabIndex);
-		tabs.at(currentTabIndex)->activate();
-	}
+	/*
+	 * Ensure that menus and timers will be properly shown,
+	 * according with the selected display mode.
+	 */
+	stackedLayout->setCurrentIndex(currentTabIndex);
+	tabs.at(currentTabIndex)->activate();
+
+	emit displayModeChanged();
 }
 
 void MainWindow::hideCursor()
@@ -798,11 +810,19 @@ bool MainWindow::event(QEvent *event)
 
 	switch (event->type()) {
 	case QEvent::Wheel: {
+		int delta, y;
+
 		QWheelEvent *wheel = static_cast<QWheelEvent *>(event);
 
-		int delta = (wheel->pixelDelta().y() < 0) ? -1 : 1;
+		y = wheel->pixelDelta().y();
+		if (!y)
+			y = wheel->angleDelta().y();
 
-		mediaWidget->setVolume(mediaWidget->getVolume() + delta);
+		if (!y)
+			break;
+		delta = (y < 0) ? -1 : 1;
+
+		mediaWidget->setVolumeUnderMouse(mediaWidget->getVolume() + delta);
 		break;
 	}
 	case QEvent::HoverMove: {
@@ -858,7 +878,9 @@ void MainWindow::keyPressEvent(QKeyEvent *event)
 void MainWindow::leaveEvent(QEvent *event)
 {
 	if (autoHideControlBar) {
+		menuBar()->setVisible(false);
 		controlBar->setVisible(false);
+		tabs.at(currentTabIndex)->mouse_move(-1, -1);
 	}
 
 	QMainWindow::leaveEvent(event);
